@@ -737,6 +737,8 @@ WITH a AS ((SELECT b.foo AS foo, b.bar AS bar FROM b) UNION ALL (SELECT c.foo AS
 WITH a AS ((SELECT 1 AS b) UNION ALL (SELECT 1 AS b)) SELECT * FROM a
 SELECT (WITH x AS (SELECT 1 AS y) SELECT * FROM x) AS z
 SELECT ((SELECT 1) + 1)
+SELECT ((SELECT 0) UNION (SELECT 1) ORDER BY 1 OFFSET 1)
+SELECT * FROM x WHERE y IN ((SELECT 1) UNION (SELECT 2) OFFSET 2)
 SELECT * FROM project.dataset.INFORMATION_SCHEMA.TABLES
 SELECT CAST(x AS INT) /* comment */ FROM foo
 SELECT c /* c1 /* c2 */ c3 */
@@ -938,4 +940,5 @@ SELECT a FROM test GROUP BY GROUPING SETS ((x + y, z))
 SELECT (LEAD(foo1, 1, 0)) OVER (PARTITION BY foo2 ORDER BY foo3) FROM t
 SELECT LAST_VALUE(CASE WHEN interval <> 'foo' THEN interval END) IGNORE NULLS FROM t
 WITH UNNEST AS (SELECT 1 AS UNNEST) SELECT UNNEST FROM UNNEST
-SELECT * FROM tbl GROUP BY GROUPING SETS ((a, b), c, CUBE (a, b), ROLLUP (c, d), (a + y, b * 1), ())
\ No newline at end of file
+SELECT * FROM tbl GROUP BY GROUPING SETS ((a + 1, b * 1), c, CUBE (a, b), ROLLUP (c, d), (a + y, b * 1), ())
+SELECT * FROM tbl GROUP BY GROUPING SETS (GROUPING SETS (course), GROUPING SETS (type), CUBE (a), ROLLUP (b))
\ No newline at end of file
